==> zio-aws-imagebuilder_2.13-5.17.158.4-sources.jar: zio/aws/imagebuilder/model/DeleteContainerRecipeResponse.scala <==
package zio.aws.imagebuilder.model
import zio.aws.imagebuilder.model.primitives.{
  ContainerRecipeArn,
  NonEmptyString
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteContainerRecipeResponse(
    requestId: Option[NonEmptyString] = None,
    containerRecipeArn: Option[ContainerRecipeArn] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.imagebuilder.model.DeleteContainerRecipeResponse = {
    import DeleteContainerRecipeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.imagebuilder.model.DeleteContainerRecipeResponse
      .builder()
      .optionallyWith(
        requestId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.requestId)
      .optionallyWith(
        containerRecipeArn.map(value =>
          ContainerRecipeArn.unwrap(value): java.lang.String
        )
      )(_.containerRecipeArn)
      .build()
  }
  def asReadOnly
      : zio.aws.imagebuilder.model.DeleteContainerRecipeResponse.ReadOnly =
    zio.aws.imagebuilder.model.DeleteContainerRecipeResponse
      .wrap(buildAwsValue())
}
object DeleteContainerRecipeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.imagebuilder.model.DeleteContainerRecipeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.imagebuilder.model.DeleteContainerRecipeResponse =
      zio.aws.imagebuilder.model.DeleteContainerRecipeResponse(
        requestId.map(value => value),
        containerRecipeArn.map(value => value)
      )
    def requestId: Option[NonEmptyString]
    def containerRecipeArn: Option[ContainerRecipeArn]
    def getRequestId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("requestId", requestId)
    def getContainerRecipeArn: ZIO[Any, AwsError, ContainerRecipeArn] =
      AwsError.unwrapOptionField("containerRecipeArn", containerRecipeArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.imagebuilder.model.DeleteContainerRecipeResponse
  ) extends zio.aws.imagebuilder.model.DeleteContainerRecipeResponse.ReadOnly {
    override val requestId: Option[NonEmptyString] = scala
      .Option(impl.requestId())
      .map(value => zio.aws.imagebuilder.model.primitives.NonEmptyString(value))
    override val containerRecipeArn: Option[ContainerRecipeArn] = scala
      .Option(impl.containerRecipeArn())
      .map(value =>
        zio.aws.imagebuilder.model.primitives.ContainerRecipeArn(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.imagebuilder.model.DeleteContainerRecipeResponse
  ): zio.aws.imagebuilder.model.DeleteContainerRecipeResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-imagebuilder_2.13-5.17.225.1-sources.jar: zio/aws/imagebuilder/model/DeleteContainerRecipeResponse.scala <==
package zio.aws.imagebuilder.model
import zio.aws.imagebuilder.model.primitives.{
  ContainerRecipeArn,
  NonEmptyString
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteContainerRecipeResponse(
    requestId: Optional[NonEmptyString] = Optional.Absent,
    containerRecipeArn: Optional[ContainerRecipeArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.imagebuilder.model.DeleteContainerRecipeResponse = {
    import DeleteContainerRecipeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.imagebuilder.model.DeleteContainerRecipeResponse
      .builder()
      .optionallyWith(
        requestId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.requestId)
      .optionallyWith(
        containerRecipeArn.map(value =>
          ContainerRecipeArn.unwrap(value): java.lang.String
        )
      )(_.containerRecipeArn)
      .build()
  }
  def asReadOnly
      : zio.aws.imagebuilder.model.DeleteContainerRecipeResponse.ReadOnly =
    zio.aws.imagebuilder.model.DeleteContainerRecipeResponse
      .wrap(buildAwsValue())
}
object DeleteContainerRecipeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.imagebuilder.model.DeleteContainerRecipeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.imagebuilder.model.DeleteContainerRecipeResponse =
      zio.aws.imagebuilder.model.DeleteContainerRecipeResponse(
        requestId.map(value => value),
        containerRecipeArn.map(value => value)
      )
    def requestId: Optional[NonEmptyString]
    def containerRecipeArn: Optional[ContainerRecipeArn]
    def getRequestId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("requestId", requestId)
    def getContainerRecipeArn: ZIO[Any, AwsError, ContainerRecipeArn] =
      AwsError.unwrapOptionField("containerRecipeArn", containerRecipeArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.imagebuilder.model.DeleteContainerRecipeResponse
  ) extends zio.aws.imagebuilder.model.DeleteContainerRecipeResponse.ReadOnly {
    override val requestId: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.requestId())
      .map(value => zio.aws.imagebuilder.model.primitives.NonEmptyString(value))
    override val containerRecipeArn: Optional[ContainerRecipeArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.containerRecipeArn())
        .map(value =>
          zio.aws.imagebuilder.model.primitives.ContainerRecipeArn(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.imagebuilder.model.DeleteContainerRecipeResponse
  ): zio.aws.imagebuilder.model.DeleteContainerRecipeResponse.ReadOnly =
    new Wrapper(impl)
}
